@@ -48,8 +48,8 @@ class CoreBackendMgmt {
      * @param   config  $MAINCFG
      * @author  Lars Michelsen <lars@vertical-visions.de>
      */
-    public function __construct($CORE) {
-        $this->CORE = $CORE;
+    public function __construct() {
+        $this->CORE = GlobalCore::getInstance();
 
         $this->loadBackends();
 
@@ -507,7 +507,7 @@ class CoreBackendMgmt {
      * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
     public function checkBackendFeature($backendId, $feature, $printErr = 1) {
-        $backendClass = 'GlobalBackend'.cfg('backend_'.$backendId,'backendtype');
+        $backendClass = 'GlobalBackend'.cfg('backend_'.$backendId, 'backendtype');
         if(method_exists($backendClass, $feature)) {
             return true;
         } else {
