@@ -33,7 +33,6 @@ class CoreModOverview extends CoreModule {
         $this->aActions = Array(
             'getOverviewProperties' => 'view',
             'getOverviewMaps'       => 'view',
-            'getOverviewAutomaps'   => 'view',
             'getOverviewRotations'  => 'view',
             'getObjectStates'       => 'view',
         );
@@ -52,16 +51,23 @@ class CoreModOverview extends CoreModule {
                 case 'getOverviewMaps':
                     $sReturn = $OVERVIEW->parseMapsJson('map');
                 break;
-                case 'getOverviewAutomaps':
-                    $sReturn = $OVERVIEW->parseMapsJson('automap');
-                break;
                 case 'getOverviewRotations':
                     $sReturn = $OVERVIEW->parseRotationsJson();
                 break;
                 case 'getObjectStates':
-                    $aOpts = Array('i'  => MATCH_STRING_NO_SPACE);
+                    $aOpts = Array(
+                        'i' => MATCH_STRING_NO_SPACE,
+                        'f' => MATCH_STRING_NO_SPACE_EMPTY,
+                    );
                     $aVals = $this->getCustomOptions($aOpts);
 
+                    // Is this request asked to check file ages?
+                    if(isset($aVals['f']) && isset($aVals['f'][0])) {
+                        $result = $this->checkFilesChanged($aVals['f']);
+                        if($result !== null)
+                            return $result;
+                    }
+
                     $sReturn = $OVERVIEW->parseMapsJson('list', COMPLETE, $aVals['i']);
                 break;
             }
