@@ -27,7 +27,6 @@
  */
 class GlobalIndexPage {
     private $CORE;
-    private $BACKEND;
     private $htmlBase;
 
 
@@ -35,20 +34,79 @@ class GlobalIndexPage {
      * Class Constructor
      *
      * @param 	GlobalCore 	$CORE
-     * @param 	CoreBackendMgmt	$BACKEND
      * @author 	Lars Michelsen <lars@vertical-visions.de>
      */
     public function __construct() {
         global $CORE;
         $this->CORE = $CORE;
-        $this->BACKEND = new CoreBackendMgmt($CORE);
         $this->htmlBase = cfg('paths','htmlbase');
     }
 
+    private function parseMapJson($objectId, $mapType, $mapName, $what) {
+        global $AUTHORISATION;
+        // Check if the user is permitted to view this
+        if(!$AUTHORISATION->isPermitted('Map', 'view', $mapName))
+            return null;
+
+        // If the parameter filterUser is set, filter the maps by the username
+        // given in this parameter. This is a mechanism to be authed as generic
+        // user but see the maps of another user. This feature is disabled by
+        // default but could be enabled if you need it.
+        if(cfg('global', 'user_filtering') && isset($_GET['filterUser']) && $_GET['filterUser'] != '') {
+            $AUTHORISATION2 = new CoreAuthorisationHandler();
+            $AUTHORISATION2->parsePermissions($_GET['filterUser']);
+            if(!$AUTHORISATION2->isPermitted('Map', 'view', $mapName))
+                return null;
+
+            // Switch the auth cookie to this user
+            global $SHANDLER;
+            $SHANDLER->aquire();
+            $SHANDLER->set('authCredentials', array('user' => $_GET['filterUser'], 'password' => ''));
+            $SHANDLER->set('authTrusted',     true);
+            $SHANDLER->commit();
+        }
+
+        $map = Array('object_id' => $objectId);
+
+        $MAPCFG = new NagVisMapCfg($this->CORE, $mapName);
+        $MAPCFG->checkMapConfigExists(true);
+        $MAPCFG->readMapConfig();
+
+        // Only perform this check with a valid config
+        if($MAPCFG->getValue(0, 'show_in_lists') != 1)
+            return null;
+
+        $objConf = $MAPCFG->getTypeDefaults('global');
+
+        $MAP = new NagVisMap($this->CORE, $MAPCFG, GET_STATE, !IS_VIEW);
+
+        // Apply default configuration to object
+        $objConf = array_merge($objConf, $this->getMapDefaultOpts($mapType, $mapName, $MAPCFG->getAlias()));
+
+        $MAP->MAPOBJ->setConfiguration($objConf);
+
+        if($MAP->MAPOBJ->checkMaintenance(0)) {
+            $map['overview_url']    = $this->htmlBase.'/index.php?mod=Map&act=view&show='.$mapName;
+            $map['overview_class']  = '';
+        } else {
+            $map['overview_class']  = 'disabled';
+            $map['overview_url']    = 'javascript:alert(\''.l('The map is in maintenance mode. Please be patient.').'\');';
+            $map['summary_output']  = l('The map is in maintenance mode. Please be patient.');
+
+            $MAP->MAPOBJ->clearMembers();
+            $MAP->MAPOBJ->setSummaryState('UNKNOWN');
+            $MAP->MAPOBJ->fetchIcon();
+        }
+
+        if(cfg('index','showmapthumbs') == 1)
+            $map['overview_image'] = $this->renderMapThumb($MAPCFG);
+
+        return array($MAP->MAPOBJ, $map);
+    }
+
     /**
-     * Parses the maps and automaps for the overview page. It is called twice on
-     * initial page load explicit for maps and automaps.
-     * Then it is called for a list of maps/automaps to return the current state
+     * Parses the maps and maps for the overview page
+     * Then it is called for a list of maps to return the current state
      * for the listed objects.
      *
      * @return	String  Json Code
@@ -56,135 +114,69 @@ class GlobalIndexPage {
      * FIXME: More cleanups, compacting and extraction of single parts
      */
     public function parseMapsJson($type, $what = COMPLETE, $objects = Array()) {
-        global $AUTHORISATION;
+        global $_BACKEND;
         // initial parsing mode: Skip processing when this type of object should not be shown
-        if($type != 'list' && !cfg('index', 'show'.$type.'s') == 1)
+        if($type != 'list' && cfg('index', 'show'.$type.'s') != 1)
             return json_encode(Array());
 
         if($type == 'list')
             $mapList = $objects;
-        elseif($type == 'automap')
-            $mapList = $this->CORE->getAvailableAutomaps();
         else
             $mapList = $this->CORE->getAvailableMaps();
 
         $aMaps = Array();
         $aObjs = Array();
-        foreach($mapList AS $mapName) {
+        foreach($mapList AS $objectId) {
             if($type == 'list') {
-                $a = explode('-', $mapName, 2);
+                $a = explode('-', $objectId, 2);
                 if(!isset($a[1]))
                     continue;
 
                 list($mapType, $mapName) = $a;
 
                 // list mode: Skip processing when this type of object should not be shown
-                if(!cfg('index', 'show'.$mapType.'s') == 1)
+                if(cfg('index', 'show'.$mapType.'s') != 1)
                     continue;
             } else {
-                $mapType = $type;
-            }
-
-            // Check if the user is permitted to view this
-            if($mapType == 'automap') {
-                if(!$AUTHORISATION->isPermitted('AutoMap', 'view', $mapName))
-                    continue;
-            } else {
-                if(!$AUTHORISATION->isPermitted('Map', 'view', $mapName))
-                    continue;
-            }
-
-            $map = Array();
-
-            if($mapType == 'automap')
-                $MAPCFG = new NagVisAutomapCfg($this->CORE, $mapName);
-            else
-                $MAPCFG = new NagVisMapCfg($this->CORE, $mapName);
-
-            if(!$MAPCFG->checkMapConfigExists(false)) {
-                $aMaps[] = $this->mapError($mapType, $mapName, 'Map configuration file does not exist.');
-                continue;
+                $mapName  = $objectId;
+                $mapType  = $type;
+                $objectId = $type . '-' . $mapName;
             }
 
             try {
-                $MAPCFG->readMapConfig();
-
-                // Only perform this check with a valid config
-                if($MAPCFG->getValue(0, 'show_in_lists') != 1)
+                $ret = $this->parseMapJson($objectId, $mapType, $mapName, $what);
+                if($ret === null) {
+                    // Skip maps which shal not be shown to the user
                     continue;
-
-                $objConf = $MAPCFG->getTypeDefaults('global');
-            } catch(MapCfgInvalid $e) {
+                }
+            } catch(Exception $e) {
                 $aMaps[] = $this->mapError($mapType, $mapName, $e->getMessage());
                 continue;
             }
 
-            if($mapType == 'automap')
-                // Only set overview specific automap params here. The default_params are added in the NagVisAutomap cnstructor
-                $MAP = new NagVisAutoMap($this->CORE, $MAPCFG, $this->BACKEND, Array('automap' => $mapName, 'preview' => 1), !IS_VIEW);
+            $aObjs[] = $ret;
+        }
+
+        // Now fetch and apply data from backend
+        $_BACKEND->execute();
+        foreach($aObjs AS $aObj) {
+            $aObj[0]->applyState();
+            $aObj[0]->fetchIcon();
+
+            if($what === ONLY_STATE)
+                $aMaps[] = array_merge($aObj[0]->getObjectStateInformations(), $aObj[1]);
             else
-                $MAP = new NagVisMap($this->CORE, $MAPCFG, $this->BACKEND, GET_STATE, !IS_VIEW);
-
-            // Apply default configuration to object
-            $objConf = array_merge($objConf, $this->getMapAndAutomapDefaultOpts($mapType, $mapName, $MAPCFG->getAlias()));
-
-            $MAP->MAPOBJ->setConfiguration($objConf);
-
-            if($MAP->MAPOBJ->checkMaintenance(0)) {
-                if($mapType == 'automap')
-                    $map['overview_url']    = $this->htmlBase.'/index.php?mod=AutoMap&act=view&show='.$mapName.$MAPCFG->getValue(0, 'default_params');
-                else
-                    $map['overview_url']    = $this->htmlBase.'/index.php?mod=Map&act=view&show='.$mapName;
-
-                $map['overview_class']  = '';
-            } else {
-                $map['overview_class']  = 'disabled';
-                $map['overview_url']    = 'javascript:alert(\''.l('The map is in maintenance mode. Please be patient.').'\');';
-                $map['summary_output']  = l('The map is in maintenance mode. Please be patient.');
-
-                $MAP->MAPOBJ->clearMembers();
-                $MAP->MAPOBJ->setSummaryState('UNKNOWN');
-                $MAP->MAPOBJ->fetchIcon();
-            }
-
-            // If this is the automap display the last rendered image
-            if($mapType == 'automap') {
-                if(cfg('index','showmapthumbs') == 1)
-                    $map['overview_image'] = $this->renderAutomapThumb($MAP);
-
-                $MAP->MAPOBJ->fetchIcon();
-
-                if($what === ONLY_STATE)
-                    $aMaps[] = array_merge($MAP->MAPOBJ->getObjectStateInformations(), $map);
-                else
-                    $aMaps[] = array_merge($MAP->MAPOBJ->parseJson(), $map);
-            } else {
-                if(cfg('index','showmapthumbs') == 1)
-                    $map['overview_image'] = $this->renderMapThumb($MAPCFG);
-
-                $aObjs[] = Array($MAP->MAPOBJ, $map);
-            }
+                $aMaps[] = array_merge($aObj[0]->parseJson(), $aObj[1]);
         }
 
-        if($type == 'map' || $type == 'list') {
-            $this->BACKEND->execute();
-
-            foreach($aObjs AS $aObj) {
-                $aObj[0]->applyState();
-                $aObj[0]->fetchIcon();
-
-                if($what === ONLY_STATE)
-                    $aMaps[] = array_merge($aObj[0]->getObjectStateInformations(), $aObj[1]);
-                else
-                    $aMaps[] = array_merge($aObj[0]->parseJson(), $aObj[1]);
-            }
+        if($type != 'list') {
+            usort($aMaps, Array('GlobalCore', 'cmpAlias'));
         }
 
-        usort($aMaps, Array('GlobalCore', 'cmpAlias'));
         return json_encode($aMaps);
     }
 
-    private function getMapAndAutomapDefaultOpts($type, $name, $alias) {
+    private function getMapDefaultOpts($type, $name, $alias) {
         return Array(
           'type'              => 'map',
           'map_name'          => $name,
@@ -200,7 +192,7 @@ class GlobalIndexPage {
     }
 
     private function mapError($type, $name, $msg) {
-        $map = $this->getMapAndAutomapDefaultOpts($type, $name, $name);
+        $map = $this->getMapDefaultOpts($type, $name, $name);
         $map['name']            = $map['map_name'];
         unset($map['map_name']);
         $map['state']           = 'ERROR';
@@ -210,7 +202,7 @@ class GlobalIndexPage {
         $map['num_members']     = 0;
         $map['overview_class']  = 'error';
         $map['overview_url']    = 'javascript:alert(\''.$msg.'\');';
-        $map['summary_output']  = l('Map Configuration Error: [ERR]', Array('ERR' => $msg));
+        $map['summary_output']  = l('Map Error: [ERR]', Array('ERR' => $msg));
         return $map;
     }
 
@@ -237,35 +229,6 @@ class GlobalIndexPage {
         return $sThumbPathHtml;
     }
 
-    private function renderAutomapThumb($MAP) {
-        $mapName = $MAP->MAPOBJ->getName();
-        $imgPath = cfg('paths', 'sharedvar') . $mapName . '.png';
-
-        // If there is no automap image on first load of the index page,
-        // render the image
-        if(!$this->checkImageExists($imgPath, false))
-            $MAP->renderMap();
-
-        // If the message still does not exist print an error and skip the thumbnail generation
-    if(!$this->checkImageExists($imgPath, false))
-            return '';
-
-        // Use large image when no gd is available
-        if(!$this->CORE->checkGd(0))
-            return cfg('paths', 'htmlsharedvar') . $mapName . '.png';
-
-        $sThumbFile     = $mapName.'-thumb.png';
-        $sThumbPath     = cfg('paths','sharedvar').$sThumbFile;
-        $sThumbPathHtml = cfg('paths','htmlsharedvar').$sThumbFile;
-
-        // Only create a new thumb when there is no cached one
-        $FCACHE = new GlobalFileCache($imgPath, $sThumbPath);
-        if($FCACHE->isCached() === -1)
-            $image = $this->createThumbnail($imgPath, $sThumbPath);
-
-        return $sThumbPathHtml;
-    }
-
     /**
      * Parses the rotations for the overview page
      *
@@ -311,7 +274,6 @@ class GlobalIndexPage {
         $arr = Array();
 
         $arr['cellsperrow']        = (int) cfg('index', 'cellsperrow');
-        $arr['showautomaps']       = (int) cfg('index', 'showautomaps');
         $arr['showmaps']           = (int) cfg('index', 'showmaps');
         $arr['showgeomap']         = (int) cfg('index', 'showgeomap');
         $arr['showmapthumbs']      = (int) cfg('index', 'showmapthumbs');
@@ -322,7 +284,6 @@ class GlobalIndexPage {
         $arr['background_color']   = cfg('index','backgroundcolor');
 
         $arr['lang_mapIndex']      = l('mapIndex');
-        $arr['lang_automapIndex']  = l('Automap Index');
         $arr['lang_rotationPools'] = l('rotationPools');
 
         $arr['event_log']          = (int) cfg('defaults', 'eventlog');
