@@ -58,7 +58,7 @@ class NagVisObject {
         $this->CORE = $CORE;
 
         // Initialize object_id (Should be overriden later)
-        $this->object_id = rand(0, 1000);
+        //$this->object_id = rand(0, 1000);
 
         $this->conf = Array();
     }
@@ -225,10 +225,10 @@ class NagVisObject {
 
         // When the childs don't need to be fetched this object is a child
         // itselfs. So much less information are needed. Progress them here
-    // If someone wants more information in hover menu children, this is
+        // If someone wants more information in hover menu children, this is
         // the place to change.
         if(!$bFetchChilds)
-      return $this->fetchObjectAsChild();
+            return $this->fetchObjectAsChild();
 
         // Need to remove some options which are not relevant
         // FIXME: Would be much better to name the needed vars explicit
@@ -242,10 +242,12 @@ class NagVisObject {
             );
 
         foreach($this AS $key => $val)
-            if(!isset(self::$arrDenyKeys[$key]))
+            if(!isset(self::$arrDenyKeys[$key]) && $val !== null)
                 $arr[$key] = $val;
 
-        $arr['num_members'] = $this->numMembers();
+        $num_members = $this->numMembers();
+        if($num_members !== null)
+            $arr['num_members'] = $this->numMembers();
 
         /**
          * FIXME: Find another place for that! This is a bad place for language strings!
@@ -314,7 +316,7 @@ class NagVisObject {
         }
 
         // I want only "name" in js
-        if($this->type != 'shape' && $this->type != 'textbox' && $this->type != 'line') {
+        if(!isset($this->CORE->statelessObjectTypes[$this->type])) {
             $arr['name'] = $this->getName();
 
             if($this->type == 'service') {
